@@ -1,29 +1,48 @@
-`signature` <- function(s){
-    if(missing(s)){  # return SOL
-        jj <- getOption("signature")
-        if(!is.null(jj)){
-            return(jj)
-        } else {
-            return(0)
-        }
-    } else { # set signature
-        stopifnot(is_ok_sig(s))
-        if(is.infinite(s)){s <- 0}
-        options("signature" = s)
-        if(isTRUE(getOption("show_signature"))){
-            options("prompt" = paste(s, "> "))
+`signature` <- function(p,q=0){
+    if(missing(p)){  # get: signature() returns c(p,q)
+        s <- getOption("signature") # s=c(p,q)
+        if(is.null(s)){
+            s <- c(.Machine$integer.max,0)
         }
+        showsig(s)
+        class(s) <- "sigobj"
         return(s)
+    } else { # p not missing, set signature
+        s <- c(p,q)
+        p <- min(s[1], .Machine$integer.max)
+        q <- min(s[2], .Machine$integer.max)
+        stopifnot(is_ok_sig(s))
+        options("signature" = c(p,q))
+        showsig(s)
+        return(invisible(s))
     }
 }
 
+`showsig` <- function(s){ # s=c(p,q)
+    if(isTRUE(getOption("show_signature"))){
+        if(s[1] == .Machine$integer.max){
+            options("prompt" = "Cl(Inf) > ")
+        } else if(all(s==0)){
+            options("prompt" = "Grassman > ")
+        } else {
+            options("prompt" = paste("Cl(", s[1],",", s[2],") > ",sep=""))
+        }
+    } 
+}
+
+`print.sigobj` <- function(x,...){
+    print(ifelse(x == .Machine$integer.max, Inf, x))
+}
+
 `is_ok_sig` <- function(s){
-    if(length(s) != 1){
-        stop("signature must have length 1")
-    } else if(s != round(s)){
+    if(length(s) != 2){
+        stop("signature must have length 2, s=c(p,q)")
+    } else if(any(s != round(s))){
       stop("signature must be an integer")
+    } else if(any(s<0)){
+        stop("p and q must be >=0")
     } else {
-      return(TRUE)
+        return(TRUE)
     }
 }
 
@@ -83,16 +102,16 @@ maxyterm <- function(C1,C2=as.clifford(0)){
             stop("Generic '^' not implemented in this case")
         }
     } else if (.Generic == "==") {
-        if(lclass && rclass){
+        if(lclass || rclass){
             return(clifford_eq_clifford(as.clifford(e1),as.clifford(e2)))
         } else {
-            stop("Generic '==' only compares two clifford objects with one another")
+            stop("Generic '==' called inappropriately")
         }
     } else if (.Generic == "!=") {
-         if(lclass && rclass){
+         if(lclass || rclass){
             return(!clifford_eq_clifford(as.clifford(e1),as.clifford(e2)))
         } else {
-            stop("Generic '==' only compares two clifford objects with one another")
+            stop("Generic '!=' called inappropriately")
         }
     }
 }
@@ -123,9 +142,16 @@ maxyterm <- function(C1,C2=as.clifford(0)){
 }
 
 `clifford_inverse` <- function(C){
-    if(signature()<0){stop("inverses not defined for Grassman algebra")}
-    stopifnot((all(grades(C)==1)) || is.pseudoscalar(C))
-    return(clifford_times_scalar(Conj(C),1/eucprod(C)))
+    if(all(signature()==0)){stop("inverses not defined for Grassman algebra")}
+
+    if((all(grades(C)==1)) || is.pseudoscalar(C)){
+        return(clifford_times_scalar(Conj(C),1/eucprod(C)))
+    }
+
+    if(nbits(C)>5){stop("inverses only defined for p+q <=5")}
+    jj <- cliffconj(C)*gradeinv(C)*rev(C)
+    jj <- jj*neg(C*jj,c(1L,4L))
+    jj/drop(zap(C*jj))
 }
 
 `clifford_plus_clifford` <- function(C1,C2){
@@ -181,6 +207,8 @@ clifford_power_scalar <- function(C,n){
 }
 
 `cliffdotprod` <- function(C1,C2){
+    C1 <- as.clifford(C1)
+    C2 <- as.clifford(C2)
     if(is.zero(C1) || is.zero(C2)){
     return(as.clifford(0))
   } else {
@@ -197,6 +225,8 @@ clifford_power_scalar <- function(C,n){
 star <- scalprod
 
 `fatdot` <- function(C1,C2){
+    C1 <- as.clifford(C1)
+    C2 <- as.clifford(C2)
     if(is.zero(C1) || is.zero(C2)){
     return(as.clifford(0))
   } else {
@@ -210,6 +240,8 @@ star <- scalprod
 }
 
 `lefttick` <- function(C1,C2){
+    C1 <- as.clifford(C1)
+    C2 <- as.clifford(C2)
     if(is.zero(C1) || is.zero(C2)){
     return(as.clifford(0))
   } else {
@@ -223,6 +255,8 @@ star <- scalprod
 }
 
 `righttick` <- function(C1,C2){
+    C1 <- as.clifford(C1)
+    C2 <- as.clifford(C2)
     if(is.zero(C1) || is.zero(C2)){
     return(as.clifford(0))
   } else {
@@ -236,6 +270,7 @@ star <- scalprod
 }
 
 "%.%" <- function(C1,C2){UseMethod("%.%")}
+"%dot%" <- function(C1,C2){UseMethod("%.%")}
 "%^%" <- function(C1,C2){UseMethod("%^%")}
 "%X%" <- function(C1,C2){UseMethod("%X%")}
 "%star%" <- function(C1,C2){UseMethod("%star%")}
@@ -254,5 +289,3 @@ star <- scalprod
 "%o%.clifford" <- function(C1,C2){fatdot(C1,C2)}
 "%_|%.clifford" <- function(C1,C2){lefttick(C1,C2)}
 "%|_%.clifford" <- function(C1,C2){righttick(C1,C2)}
-
-
